import express from 'express';
import path from 'path';
import cookieParser from 'cookie-parser';

import CaptchaRouter from './routers/captcha.js';
import FrontendRouter from './routers/frontend.js';

import config from './config.js';
import UserRouter from './routers/user.js';

const app = express();

app.use(express.static(path.join('./public')));
app.use(express.urlencoded({ extended: false }));
app.use(express.json());
app.use(cookieParser());

app.get('/api/settings', (req, res) => {
    return res.status(200).send(
        {
            "captcha_source_url": config.captcha_source_url,
            "captcha_regex": config.captcha_regex,
            "captcha_length": config.captcha_length
        }
    )
})

app.set('view engine', 'pug');

app.use('/api', CaptchaRouter);
app.use('/api', UserRouter);
app.use('/', FrontendRouter);

const server = app.listen(config.app_port, () => {
    console.log("App has been started!");
});

export default server;
